@@ -3,7 +3,7 @@ package Net::MQTT::Simple;
 # use strict;    # might not be available (e.g. on openwrt)
 # use warnings;  # same.
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 
 my $global;
 my $socket_class =
@@ -74,7 +74,7 @@ sub _prepend_variable_length {
 sub _send {
     my ($self, $data) = @_;
     my $socket = $self->{socket};
-    print $socket $data;
+    syswrite $socket, $data;
 }
 
 sub _publish {
@@ -136,12 +136,12 @@ Net::MQTT::Simple - Minimal MQTT version 3 publisher
 
     use Net::MQTT::Simple;
 
-    my $mqtt1 = Net::MQTT::simple->new("mosquitto.example.org");
-    my $mqtt2 = Net::MQTT::simple->new("mosquitto.example.com");
+    my $mqtt1 = Net::MQTT::Simple->new("mosquitto.example.org");
+    my $mqtt2 = Net::MQTT::Simple->new("mosquitto.example.com");
 
     for my $server ($mqtt1, $mqtt2) {
-        $server->publish("topic/here", "Message here");
-        $server->retain( "topic/here", "Message here");
+        $server->publish("topic/here" => "Message here");
+        $server->retain( "topic/here" => "Message here");
     }
 
 
